@@ -19,11 +19,12 @@ from django.core.context_processors import csrf
 from django.core.urlresolvers import reverse, resolve
 from django.http import HttpResponse, HttpResponseBadRequest, \
     HttpResponseForbidden, HttpResponseRedirect, Http404, HttpResponseNotModified, \
-    HttpResponseNotAllowed, HttpResponseGone
+    HttpResponseGone
 from django.shortcuts import get_object_or_404
 from django.template.loader import render_to_string
 from django.utils.encoding import smart_str
 from django.views.decorators.csrf import csrf_protect, csrf_exempt
+from django.views.decorators.http import require_http_methods
 
 from sentry.conf import settings
 from sentry.models import GroupedMessage, Message
@@ -33,7 +34,8 @@ from sentry.utils import get_filters, is_float, get_signature, parse_auth_header
 from sentry.utils.compat import pickle
 from sentry.utils.stacks import get_template_info
 
-uuid_re = re.compile(r'^[a-z0-9]{32}$')
+uuid_re = re.compile(r'^[a-z0-9]{32}$', re.I)
+message_re = re.compile(r'^(?P<message_id>[a-z0-9]{32})\$(?P<checksum>[a-z0-9]{32})$', re.I)
 
 _LOGIN_URL = None
 def get_login_url(reset=False):
@@ -141,7 +143,21 @@ def search(request):
     has_search = bool(settings.SEARCH_ENGINE)
 
     if query:
-        if uuid_re.match(query):
+        result = message_re.match(query)
+        if result:
+            # Forward to message if it exists
+            message_id = result.group(1)
+            checksum = result.group(2)
+            try:
+                message = GroupedMessage.objects.get(checksum=checksum)
+            except GroupedMessage.DoesNotExist:
+                if not has_search:
+                    return render_to_response('sentry/invalid_message_id.html')
+                else:
+                    message_list = get_search_query_set(query)
+            else:
+                return HttpResponseRedirect(message.get_absolute_url())
+        elif uuid_re.match(query):
             # Forward to message if it exists
             try:
                 message = Message.objects.get(message_id=query)
@@ -473,10 +489,8 @@ def group_message_details(request, group_id, message_id):
     })
 
 @csrf_exempt
+@require_http_methods(['POST'])
 def store(request):
-    if request.method != 'POST':
-        return HttpResponseNotAllowed('This method only supports POST requests')
-
     if request.META.get('HTTP_AUTHORIZATION', '').startswith('Sentry'):
         auth_vars = parse_auth_header(request.META['HTTP_AUTHORIZATION'])
 
